@@ -150,7 +150,7 @@ setMethodS3("byChipType", "AromaChipTypeAnnotationFile", function(static, chipTy
   if (is.null(pathname)) {
     ext <- getDefaultExtension(static);
     note <- attr(ext, "note");
-    msg <- sprintf("Failed to create %s object. Could to locate an annotation data file for chip type '%s'", class(static)[1], chipType);
+    msg <- sprintf("Failed to create %s object. Could not locate an annotation data file for chip type '%s'", class(static)[1], chipType);
     if (is.null(tags)) {
       msg <- sprintf("%s (without requiring any tags)", msg);
     } else {
@@ -282,6 +282,9 @@ setMethodS3("getChipType", "AromaChipTypeAnnotationFile", abstract=TRUE);
 
 ############################################################################
 # HISTORY:
+# 2012-06-18
+# o FIX: Fixed a type in an error message generated by byChipType()
+#   for AromaChipTypeAnnotationFile.
 # 2011-11-19
 # o Now byChipType() for AromaChipTypeAnnotationFile gives an error
 #   message with more information on which file it failed to locate,
