@@ -1,4 +1,15 @@
 setMethodS3("calculateResidualSet", "ProbeLevelModel", function(this, units=NULL, force=FALSE, ..., verbose=FALSE) {
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Local functions
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  qsort <- function(x) {
+##    o0 <- .Internal(qsort(x, TRUE));
+##    o <- sort.int(x, index.return=TRUE, method="quick");
+##    stopifnot(identical(o, o0));
+    sort.int(x, index.return=TRUE, method="quick");
+  } # qsort()
+
+
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -159,10 +170,12 @@ setMethodS3("calculateResidualSet", "ProbeLevelModel", function(this, units=NULL
   }
 
   # Optimized reading order
-  o <- .Internal(qsort(cells, TRUE));
+  # WAS: o <- .Internal(qsort(cells, TRUE));
+  o <- qsort(cells);
   cells <- o$x;
   o <- o$ix;
-  oinv <- .Internal(qsort(o, TRUE))$ix;
+  # WAS: oinv <- .Internal(qsort(o, TRUE))$ix;
+  oinv <- qsort(o)$ix;
   
   # Garbage collect
   gc <- gc();
@@ -316,6 +329,10 @@ setMethodS3("calculateResiduals", "ProbeLevelModel", function(this, ...) {
 
 ############################################################################
 # HISTORY:
+# 2012-03-23
+# o Now local qsort() utilizes sort.int() instead of .Internal(qsort()).
+# 2012-03-01
+# o Added local function qsort() to calculateResidualSet().
 # 2007-12-08
 # o Now calculateResidualSet() of ProbeLevelModel utilizes the new 'cdf'
 #   argument of fromFiles() in AffymetrixCelSet.
