@@ -37,6 +37,7 @@ setMethodS3("doCRMAv2", "AffymetrixCelSet", function(csR, combineAlleles=TRUE, l
   verbose && str(verbose, arraysTag);
   verbose && cat(verbose, "ram: ", ram);
 
+
   # List of objects to be returned
   res <- list();
   if (!drop) {
@@ -44,6 +45,9 @@ setMethodS3("doCRMAv2", "AffymetrixCelSet", function(csR, combineAlleles=TRUE, l
   }
 
 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # Setup data set to be processed
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   verbose && cat(verbose, "Data set");
   verbose && print(verbose, csR);
 
@@ -55,6 +59,94 @@ setMethodS3("doCRMAv2", "AffymetrixCelSet", function(csR, combineAlleles=TRUE, l
     verbose && exit(verbose);
   }
 
+
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # Check if the final results are already available?
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  if (drop) {
+    verbose && enter(verbose, "Checking whether final results are available or not");
+
+    # The name, tags and chip type and array names of the results to look for
+    dataSet <- getFullName(csR);
+    cdf <- getCdf(csR);
+    chipType <- getChipType(cdf);
+
+    # The fullnames of all arrays that should exist
+    fullnames <- getFullNames(csR);
+
+    # ACC tags
+    # From the constructor of AllelicCrosstalkCalibration
+    if (regexpr("^Mapping[0-9]+K_", chipType) != -1) {
+      rescaleBy <- "groups";
+    } else if (regexpr("^GenomeWideSNP_", chipType) != -1) {
+      rescaleBy <- "all";
+    } else if (regexpr("^Cyto(genetics|ScanHD)_Array$", chipType) != -1) {
+      rescaleBy <- "all";
+    } else if (regexpr("^MOUSEDIVm520650$", chipType) != -1) {
+      rescaleBy <- "all";
+    } else {
+      # Heuristics so that we can work with "future/unknown" chip types.
+      types <- getUnitTypes(cdf);
+      # 5 == Copy Number
+      hasCns <- is.element(5, types);
+      rm(types);
+      if (hasCns) {
+        rescaleBy <- "all";
+      } else {
+        rescaleBy <- "groups";
+      }
+    }
+    accTags <- c("ACC", switch(rescaleBy, all="ra", none="rn"), "-XY");
+    accTags <- paste(accTags, collapse=",");
+
+    # PLM tags
+    plmTags <- switch(plm, "AvgCnPlm"="AVG", "RmaCnPlm"="RMA");
+    if (combineAlleles) {
+      plmTags <- c(plmTags, "A+B");
+    }
+
+    tags <- c(accTags, "BPN,-XY", plmTags, "FLN,-XY");
+
+    # Try to load the final TCN data set
+    dsT <- tryCatch({
+      ds <- AromaUnitTotalCnBinarySet$byName(dataSet, tags=tags, chipType=chipType);
+      extract(ds, fullnames, onMissing="error");
+    }, error=function(ex) { NULL });
+
+    # Continue?
+    if (!is.null(dsT)) {
+      # Done?
+      if (combineAlleles) {
+        verbose && cat(verbose, "Already done.");
+        verbose && print(verbose, dsT);
+        verbose && exit(verbose);
+        verbose && exit(verbose);
+        return(dsT);
+      }
+
+      # Try to load the final BAF data set
+      dsB <- tryCatch({
+        ds <- AromaUnitFracBCnBinarySet$byName(dataSet, tags=tags, chipType=chipType);
+        extract(ds, fullnames, onMissing="error");
+      }, error=function(ex) { NULL });
+
+      # Done?
+      if (!is.null(dsB)) {
+        verbose && cat(verbose, "Already done.");
+        dsList <- list(total=dsT, fracB=dsB);
+        verbose && print(verbose, dsList);
+        verbose && exit(verbose);
+        verbose && exit(verbose);
+        return(dsList);
+      }
+    } # if (!is.null(dsT))
+    verbose && exit(verbose);
+  } # if (drop)
+
+
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # CRMAv2
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   verbose && enter(verbose, "CRMAv2/Allelic crosstalk calibration");
   acc <- AllelicCrosstalkCalibration(csR, model="CRMAv2");
   verbose && print(verbose, acc);
@@ -189,6 +281,9 @@ setMethodS3("doASCRMAv2", "default", function(...) {
 
 ############################################################################
 # HISTORY:
+# 2012-08-24
+# o SPEED UP: Now doCRMAv2() will check upfront if the final results are
+#   already available.  If they are, they will be returned instantaneously.
 # 2011-04-07
 # o Added argument 'drop'.
 # 2011-03-14
